Learn R Programming

Rnaught (version 0.1.0)

COVIDCanadaPT: COVID-19 Canada Provincial and Territorial Case Counts, 2020-2023

Description

Daily COVID-19 case counts for each Canadian province and territory, from the start of the pandemic until the end of 2023. Retrieved from the the COVID-19 Canada Open Data Working Group on 2024-05-11.

Usage

COVIDCanadaPT

Arguments

Format

A data frame with 16799 observations on 4 variables:

region

The two-letter code for the Canadian province or territory.

date

The date of reporting in YYYY-MM-DD format.

cases

The daily number of cases.

cumulative_cases

The cumulative number of cases.