Daily COVID-19 case counts for each Canadian province and territory, from the start of the pandemic until the end of 2023. Retrieved from the the COVID-19 Canada Open Data Working Group on 2024-05-11.
COVIDCanadaPTA data frame with 16799 observations on 4 variables:
The two-letter code for the Canadian province or territory.
The date of reporting in YYYY-MM-DD format.
The daily number of cases.
The cumulative number of cases.